0.2.2
+++++
Fix bug sending mails to multpile recipients.
Add Bcc and Cc fields.

0.2.0
++++++++++++++++++++++++++++++
Stop relying on Mailtools.
letter.Letter interface for SMTP messages as well.

0.1.0
++++++++++++++++++
Add a Django compatibility layer for composing emails there.
Write the letter.Letter class based interface.

0.0.3
++++++++++++++++++
Forgive nonexistant directories on the temlpate search path.

0.0.2 (09 10 2012)
++++++++++++++++++

Initial version
